A lightweight ``PostgREST`` proxy that does not get in your way.

Installing
==========

.. code-block:: bash

  pip3 install aiodata

Links
-----

- `Documentation <https://aiodata.readthedocs.io>`_
